setwd("***/data/")
library(readstata13)
library(interflex)
library(ggpubr)

all <- read.dta13("IVs30_NOexclusion.dta", generate.factors = TRUE, 
                     convert.factors = FALSE, nonint.factors = TRUE) ##import data

div <- read.dta13("IVs30_divis.dta", generate.factors = TRUE, 
                      convert.factors = FALSE, nonint.factors = TRUE) ##import data


inter.raw(Y = "csim30_tr_diff", D = "RILE", X = "EU", data = all, 
          Ylabel = "Disagreement", Dlabel = "RILE", Xlabel="EU", 
          theme.bw = TRUE, show.grid = FALSE)

inter.raw(Y = "csim30_tr_diff", D = "RILE", X = "EU", data = div, 
          Ylabel = "Disagreement", Dlabel = "RILE", Xlabel="EU", 
          theme.bw = TRUE, show.grid = FALSE)

z <- c("gdp_evol", 'Unemployement',
       "debt_gdp", "target", "entryEU57","eurobar", "trustECB", "credit", "spread", "inflation_abs_perc")



bin_all <- inter.binning(Y = "csim30_tr_diff", D = "RILE", X = "EU", Z = z, 
              data = all, theme.bw = TRUE, 
              Ylabel = "Disagreement", Dlabel = "RILE", Xlabel="EU",
              vartype = "pcse", cl = "country", time = "year")$graph

bin_div <- inter.binning(Y = "csim30_tr_diff", D = "RILE", X = "EU", Z = z, 
                         data = div, theme.bw = TRUE, 
                         Ylabel = "Disagreement", Dlabel = "RILE", Xlabel="EU",
                         vartype = "pcse", cl = "country", time = "year")$graph

kern_all <- inter.kernel(Y = "csim30_tr_diff", D = "RILE", X = "EU", Z =  z,
             data = all, Ylabel = "Disagreement", Dlabel = "RILE", Xlabel="EU")$graph

kern_div <- inter.kernel(Y = "csim30_tr_diff", D = "RILE", X = "EU", Z =  z,
                         data = div, Ylabel = "Disagreement", Dlabel = "RILE", Xlabel="EU")$graph

fig <- ggarrange(bin_all + rremove("ylab") + rremove("xlab"), 
          bin_div + rremove("ylab") + rremove("xlab"), 
          kern_all + rremove("ylab") + rremove("xlab"), 
          kern_div + rremove("ylab") + rremove("xlab"), 
          labels = c("a) Binning, All topics", "b) Binning, Divisive topics", 
                     "c) Kernel, All topics", "d) Kernel, divisive topics"),
          ncol = 2, nrow = 2)

annotate_figure(fig,
                bottom = text_grob("Moderator: EU", size = 14),
                left = text_grob("Marginal effect of LEFT-WING on DISAGREEMENT", rot = 90, size = 14),
)
